==> physx-jni-0.4.0-sources.jar: physx/physics/PxConstraintInfo.java <==
package physx.physics;

import physx.NativeObject;

public class PxConstraintInfo extends NativeObject {

    protected PxConstraintInfo() { }

    public static PxConstraintInfo wrapPointer(long address) {
        return new PxConstraintInfo(address);
    }
    
    protected PxConstraintInfo(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxConstraint}
     */
    public PxConstraint getConstraint() {
        return PxConstraint.wrapPointer(_getConstraint(address));
    }
    private static native long _getConstraint(long address);

    /**
     * @param value WebIDL type: {@link PxConstraint}
     */
    public void setConstraint(PxConstraint value) {
        _setConstraint(address, value.getAddress());
    }
    private static native void _setConstraint(long address, long value);

    /**
     * @return WebIDL type: VoidPtr
     */
    public NativeObject getExternalReference() {
        return NativeObject.wrapPointer(_getExternalReference(address));
    }
    private static native long _getExternalReference(long address);

    /**
     * @param value WebIDL type: VoidPtr
     */
    public void setExternalReference(NativeObject value) {
        _setExternalReference(address, value.getAddress());
    }
    private static native void _setExternalReference(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getType() {
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setType(int value) {
        _setType(address, value);
    }
    private static native void _setType(long address, int value);

}

==> physx-jni-0.4.1-sources.jar: physx/physics/PxConstraintInfo.java <==
package physx.physics;

import physx.NativeObject;

public class PxConstraintInfo extends NativeObject {

    protected PxConstraintInfo() { }

    public static PxConstraintInfo wrapPointer(long address) {
        return address != 0L ? new PxConstraintInfo(address) : null;
    }
    
    protected PxConstraintInfo(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxConstraint}
     */
    public PxConstraint getConstraint() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxConstraint.wrapPointer(_getConstraint(address));
    }
    private static native long _getConstraint(long address);

    /**
     * @param value WebIDL type: {@link PxConstraint}
     */
    public void setConstraint(PxConstraint value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setConstraint(address, value.getAddress());
    }
    private static native void _setConstraint(long address, long value);

    /**
     * @return WebIDL type: VoidPtr
     */
    public NativeObject getExternalReference() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return NativeObject.wrapPointer(_getExternalReference(address));
    }
    private static native long _getExternalReference(long address);

    /**
     * @param value WebIDL type: VoidPtr
     */
    public void setExternalReference(NativeObject value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setExternalReference(address, value.getAddress());
    }
    private static native void _setExternalReference(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getType() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setType(int value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setType(address, value);
    }
    private static native void _setType(long address, int value);

}
